Scroller examples - Initialisation

# Scroller example Initialisation

The examples in this section demonstrate Scroller's initialisation and options.

### Initialisation

- Basic initialisation
- State saving
- Client-side data source (50,000 rows)
- Server-side processing (5,000,000 rows)
- API
- FixedColumns integration
- Select integration

Please refer to the DataTables documentation for full information about its API properties and methods.
Additionally, there are a wide range of extensions and plug-ins which extend the capabilities of DataTables.

DataTables designed and created by SpryMedia Ltd © 2007-2016
DataTables is licensed under the MIT license.